import { request, getRequestParameter } from '@/utils/request';
import qs from 'qs';

/**
 * @description 创建课程
 * @param {Object} Parameter
 */
export function CreateCourse(Parameter) {
  let data = getRequestParameter('teaching-course_manager-CreateCourse', JSON.stringify(Parameter));

  // 解决传数组的问题
  return request({
    method: 'post',
    url: process.env.VUE_APP_LearnWebSI,
    data,
    transformRequest: [
      function (data) {
        return qs.stringify(data);
      }
    ],
    headers: {
      'Content-Type': 'application/x-www-form-urlencoded;charset=UTF-8'
    }
  });
}

/**
 * @description 得到课程信息（包含课节信息）
 * @param {Object} id 课程ID
 */
export function GetCourseInfo_ContainCSItem(Parameter) {
  let params = getRequestParameter(
    'teaching-course_manager-GetCourseInfo_ContainCSItem',
    Parameter
  );
  return request({
    method: 'post',
    url: process.env.VUE_APP_LearnWebSI,
    params
  });
}

/**
 * @description 添加教材到课程
 * @param {Object} course_id 课程id book_id 教材ID
 */
export function AddBookToCourse(Parameter) {
  let params = getRequestParameter('teaching-course_manager-AddBookToCourse', Parameter);
  return request({
    method: 'post',
    url: process.env.VUE_APP_LearnWebSI,
    params
  });
}

/**
 * @description 从课程移除教材
 * @param {Object} course_id 课程ID book_id 教材ID
 */
export function RemoveBookFromCourse(Parameter) {
  let params = getRequestParameter('teaching-course_manager-RemoveBookFromCourse', Parameter);
  return request({
    method: 'post',
    url: process.env.VUE_APP_LearnWebSI,
    params
  });
}

/**
 * @description 添加课节到课程
 * @param {Object} Parameter course_id 课程ID begin_time 开始时间 end_time 截止时间 name 课节名称
 */
export function AddCSItemToCourse(Parameter) {
  let params = getRequestParameter('teaching-cs_item_manager-AddCSItemToCourse', Parameter);
  return request({
    method: 'post',
    url: process.env.VUE_APP_LearnWebSI,
    params
  });
}

/**
 * @description 得到课节详情（信息集合）
 * @param {Object} Parameter id 课次id
 */
export function GetCSItemInfoBox(Parameter) {
  let params = getRequestParameter('teaching-cs_item_manager-GetCSItemInfoBox', Parameter);
  return request({
    method: 'post',
    url: process.env.VUE_APP_LearnWebSI,
    params
  });
}

/**
 * @description 删除课节
 * @param {Object} Parameter id 课次ID
 */
export function DeleteCSItem(Parameter) {
  let params = getRequestParameter('teaching-cs_item_manager-DeleteCSItem', Parameter);
  return request({
    method: 'post',
    url: process.env.VUE_APP_LearnWebSI,
    params
  });
}
